.. _tensor_module:

======
Tensor
======

.. automodule:: sympy.tensor

Contents
========

.. toctree::
   :titlesonly:

   array.rst
   array_expressions.rst
   indexed.rst
   index_methods.rst
   tensor.rst
   toperators.rst
